genshi.template.plugin.MarkupTemplateEnginePlugin

Package genshi :: Package template :: Module plugin :: Class MarkupTemplateEnginePlugin |

# Class MarkupTemplateEnginePlugin

                      object --+
                               |
    AbstractTemplateEnginePlugin --+
                                   |
                                  MarkupTemplateEnginePlugin

Implementation of the plugin API for markup templates.

Nested Classes
| template_class Implementation of the template language for XML-based templates.

Instance Methods
__init__(self, extra_vars_func=None, options=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
transform(self, info, template) Render the output to an event stream. |
Inherited from `AbstractTemplateEnginePlugin`: `load_template`, `render` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| extension = ``'``.html``'`` hash(x)

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, extra_vars_func=None, options=None) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### transform(self, info, template) |
Render the output to an event stream. Overrides: AbstractTemplateEnginePlugin.transform